@@ -5,24 +5,19 @@ This module contains the events when clicking on interactive menu bar components
 """
 
 import os
-import time
 import subprocess
 import webbrowser
 
-from ..base import PolychromaticBase
-from .. import common
-from .. import preferences
-from .. import procpid
-from . import shared
-from . import procviewer
-from . import troubleshooter
+from PyQt6.QtCore import QSize, Qt
+from PyQt6.QtGui import QAction, QIcon
+from PyQt6.QtWidgets import (QButtonGroup, QDialog, QLabel, QListWidget,
+                             QListWidgetItem, QMenuBar, QMessageBox,
+                             QPushButton, QTextEdit, QTreeWidget,
+                             QTreeWidgetItem, QWidget)
 
-from PyQt5.QtCore import Qt, QSize
-from PyQt5.QtGui import QBrush, QPixmap, QFont, QIcon
-from PyQt5.QtWidgets import QWidget, QMenuBar, QMenu, QAction, QLabel, QDialog, \
-                            QPushButton, QTreeWidget, QTreeWidgetItem, \
-                            QTextEdit, QButtonGroup, QProgressBar, QMessageBox, \
-                            QApplication, QListWidget, QListWidgetItem
+from .. import common, preferences, procpid
+from ..base import PolychromaticBase
+from . import procviewer, shared, troubleshooter
 
 
 class MenuBar(PolychromaticBase):
@@ -137,15 +132,12 @@ class MenuBar(PolychromaticBase):
 
     def import_effect(self):
         self.appdata.tab_effects.import_effect()
-        pass
 
     def new_preset(self):
         print("stub:menubar.new_preset")
-        pass
 
     def new_preset_now(self):
         print("stub:menubar.new_preset_now")
-        pass
 
     def hide_menu_bar(self):
         """
@@ -324,8 +316,8 @@ class MenuBar(PolychromaticBase):
         window_title = ' '.join(sub[:1].upper() + sub[1:] for sub in title.split(' '))
         about.setWindowTitle(self._("About []").replace("[]", window_title))
         about.setWindowIcon(QIcon(logo))
-        about.setWindowFlag(Qt.WindowMinimizeButtonHint, False)
-        about.setWindowFlag(Qt.WindowMaximizeButtonHint, False)
+        about.setWindowFlag(Qt.WindowType.WindowMinimizeButtonHint, False)
+        about.setWindowFlag(Qt.WindowType.WindowMaximizeButtonHint, False)
         about.exec()
 
     def about_polychromatic(self):
@@ -342,7 +334,7 @@ class MenuBar(PolychromaticBase):
         ]
 
         versions = self.appdata.versions
-        self._show_aboutbox("polychromatic {0}".format(versions[0][1]), logo, "https://polychromatic.app", versions, license, links)
+        self._show_aboutbox(f"polychromatic {versions[0][1]} {'[Flatpak]' if self.appdata.flatpak_mode else ''}".strip(), logo, "https://polychromatic.app", versions, license, links)
 
 
 class MenuBarOpenRazer(MenuBar):
@@ -361,6 +353,7 @@ class MenuBarOpenRazer(MenuBar):
         self.url_src = "https://github.com/openrazer/openrazer/"
         self.url_bugs = "https://github.com/openrazer/openrazer/issues"
         self.url_latest = "https://github.com/openrazer/openrazer/releases/latest"
+        self.url_troubleshoot = "https://github.com/openrazer/openrazer/wiki/Troubleshooting"
 
     def _refresh(self):
         """
@@ -420,9 +413,9 @@ class MenuBarOpenRazer(MenuBar):
         self.widgets.open_dialog(self.widgets.dialog_generic,
                                  self._("Reload application?"),
                                  self._("To apply these changes, a daemon process needs to restart. This will also restart Polychromatic. Any unsaved data will be lost."),
-                                 buttons=[QMessageBox.Ok, QMessageBox.Cancel],
-                                 default_button=QMessageBox.Ok,
-                                 actions={QMessageBox.Ok: _reload_openrazer})
+                                 buttons=[QMessageBox.StandardButton.Ok, QMessageBox.StandardButton.Cancel],
+                                 default_button=QMessageBox.StandardButton.Ok,
+                                 actions={QMessageBox.StandardButton.Ok: _reload_openrazer})
 
     def _get_dbus_version(self):
         """
@@ -448,6 +441,9 @@ class MenuBarOpenRazer(MenuBar):
             return "[Unknown]"
 
     def troubleshoot(self):
+        if self.appdata.flatpak_mode:
+            webbrowser.open(self.url_troubleshoot)
+            return
         self.troubleshooter = troubleshooter.TroubleshooterGUI(self.appdata, "openrazer", "OpenRazer")
 
     def about(self):
