@@ -4,24 +4,18 @@
 This module controls the 'Preferences' window of the Controller GUI.
 """
 
-from ..base import PolychromaticBase
-from .. import common
-from .. import effects
-from .. import locales
-from .. import middleman
-from .. import procpid
-from .. import preferences as pref
-from . import shared
-
-import os
 import configparser
+import os
 
-from PyQt5.QtCore import Qt
-from PyQt5.QtGui import QIcon, QPixmap
-from PyQt5.QtWidgets import QWidget, QPushButton, QTreeWidget, QLabel, \
-                            QComboBox, QCheckBox, QDialog, QSpinBox, \
-                            QDoubleSpinBox, QDialogButtonBox, QTabWidget, \
-                            QMessageBox, QAction, QToolButton
+from PyQt6.QtGui import QAction, QIcon
+from PyQt6.QtWidgets import (QCheckBox, QComboBox, QDialog, QDialogButtonBox,
+                             QDoubleSpinBox, QLabel, QMessageBox, QPushButton,
+                             QSpinBox, QTabWidget, QWidget)
+
+from .. import preferences as pref
+from .. import procpid
+from ..base import PolychromaticBase
+from . import shared
 
 
 class PreferencesWindow(shared.TabData):
@@ -148,6 +142,12 @@ class PreferencesWindow(shared.TabData):
         except KeyError:
             pass
 
+        # Tray applet not available under Flatpak
+        if self.appdata.flatpak_mode:
+            self.dialog.findChild(QTabWidget, "PreferencesTabs").setTabEnabled(1, False)
+            self.dialog.findChild(QTabWidget, "PreferencesTabs").setTabToolTip(1, self._("Not available under Flatpak"))
+            self.dialog.findChild(QWidget, "tray").setEnabled(False)
+
         # Show time!
         self.dialog.findChild(QTabWidget, "PreferencesTabs").setCurrentIndex(open_tab if open_tab else 0)
         self.dialog.open()
@@ -236,9 +236,9 @@ class PreferencesWindow(shared.TabData):
             self.widgets.open_dialog(self.widgets.dialog_generic,
                                      self._("Restart Required"),
                                      self._("To apply these changes, the application must be restarted. Any unsaved changes will be lost."),
-                                     buttons=[QMessageBox.Ok, QMessageBox.Ignore],
-                                     default_button=QMessageBox.Ok,
-                                     actions={QMessageBox.Ok: _cb_restart_now})
+                                     buttons=[QMessageBox.StandardButton.Ok, QMessageBox.StandardButton.Ignore],
+                                     default_button=QMessageBox.StandardButton.Ok,
+                                     actions={QMessageBox.StandardButton.Ok: _cb_restart_now})
 
         # Reload tray applet
         if self.restart_applet:
@@ -268,9 +268,9 @@ class PreferencesWindow(shared.TabData):
         self.widgets.open_dialog(self.widgets.dialog_generic,
                                  self._("Reset to Default Colours"),
                                  self._("All colours in the list will be reset. Continue?"),
-                                 buttons=[QMessageBox.Ok, QMessageBox.Cancel],
-                                 default_button=QMessageBox.Ok,
-                                 actions={QMessageBox.Ok: _cb_reset_colours})
+                                 buttons=[QMessageBox.StandardButton.Ok, QMessageBox.StandardButton.Cancel],
+                                 default_button=QMessageBox.StandardButton.Ok,
+                                 actions={QMessageBox.StandardButton.Ok: _cb_reset_colours})
 
 
 class OpenRazerPreferences(shared.TabData):
